@@ -27,7 +27,6 @@ class ClientUI():
         except:
             print("密码或账号错误")
             exit()
-        playsound("getmsg.wav")
         self.root=tkinter.Tk()
         self.root.title("Web hyChat聊天室(用户昵称:"+self.text[1]+")")
         self.root.iconbitmap('hychaticon.ico')
@@ -123,7 +122,6 @@ class ClientUI():
         #格式化当前的时间
         if self.flag==True:
             self.clientSock.send(info.encode('gbk'))
-            playsound("logined.wav")
             self.inputText.delete(0.0, message.__len__() - 1.0)
             import time
             time.sleep(0.5)
